##  Prerequisites
Before you begin:
  * Ensure you're the designated S-user administrator. Learn more about the administrator concept in [About the User, Authorization and Administrator Concept![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.sap.com%2Fcontent%2Fs4m%2Fhelp%2Faccess%2Fuser-admin-concept.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://support.sap.com/content/s4m/help/access/user-admin-concept.html").
  * You must have access to SAP for Me. Learn how to get access in [Access and Authorizations![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.sap.com%2Fcontent%2Fs4m%2Fhelp%2Faccess.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://support.sap.com/content/s4m/help/access.html").
